@@ -25,9 +25,14 @@ class EODRetriever(FileSource):
             assert not kwargs
             kwargs = args[0]
 
+        self.source_kwargs = self.request(**kwargs)
+
         self.client = ecmwf.opendata.Client(source=source, preserve_request_order=True)
 
-        self.path = self._retrieve(self.request(**kwargs))
+        self.path = self._retrieve(self.source_kwargs)
+
+    def connect_to_mirror(self, mirror):
+        return mirror.connection_for_eod(self)
 
     def _retrieve(self, request):
         def retrieve(target, request):
