@@ -32,7 +32,6 @@ class FileSourceMeta(type(Source), type(os.PathLike)):
 class FileSource(Source, os.PathLike, metaclass=FileSourceMeta):
 
     _reader_ = None
-    _mutator = None
 
     def __init__(self, path=None, filter=None, merger=None):
         self.path = path
@@ -41,11 +40,6 @@ class FileSource(Source, os.PathLike, metaclass=FileSourceMeta):
 
     def mutate(self):
 
-        if self._mutator:
-            source = self._mutator.mutate_source()
-            source._parent = self
-            return source
-
         if isinstance(self.path, (list, tuple)):
             if len(self.path) == 1:
                 self.path = self.path[0]
@@ -126,15 +120,14 @@ class FileSource(Source, os.PathLike, metaclass=FileSourceMeta):
 
     def __repr__(self):
         cache_dir = SETTINGS.get("cache-directory")
-        path = self.path
-        if isinstance(self.path, str):
+        path = getattr(self, "path", None)
+        if isinstance(path, str):
             path = path.replace(cache_dir, "CACHE:")
-        # reader_class_name = str(self._reader.__class__.name)
         try:
-            reader_class_name = str(self._reader.__class__.name)
-        except AttributeError as e:  # TODO: improve this
-            reader_class_name = str(e)  # "unknown"
-        except:  # TODO: improve this # noqa: E722
+            reader_class_name = str(self._reader.__class__.__name__)
+        except AttributeError as e:
+            reader_class_name = str(e)
+        except:  # noqa: E722
             reader_class_name = "Unknown"
         return f"{self.__class__.__name__}({path},{reader_class_name})"
 
