@@ -15,7 +15,6 @@ from multiurl import Downloader
 from climetlab.core.settings import SETTINGS
 from climetlab.core.statistics import record_statistics
 from climetlab.utils import tqdm
-from climetlab.utils.mirror import get_mirrors
 
 from .file import FileSource
 
@@ -57,16 +56,11 @@ class Url(FileSource):
         extension = None
 
         self.url = url
+        self.parts = parts
         LOG.debug("URL %s", url)
 
         self.update_if_out_of_date = update_if_out_of_date
 
-        mirrors = get_mirrors()
-        mutator = mirrors.mutator(self)
-        if mutator:
-            self._mutator = mutator
-            return
-
         self.downloader = Downloader(
             url,
             chunk_size=chunk_size,
@@ -107,16 +101,8 @@ class Url(FileSource):
             force=force,
         )
 
-        mirrors.copy(self)
-
-    def is_contained_by_mirror(self, mirror, **kwargs):
-        return mirror.contains_url(self, **kwargs)
-
-    def get_mirror_mutator(self, mirror, **kwargs):
-        return mirror.mutator_for_url(self, **kwargs)
-
-    def copy_to_mirror(self, mirror, **kwargs):
-        return mirror.copy_url(self, **kwargs)
+    def connect_to_mirror(self, mirror):
+        return mirror.connection_for_url(self, self.url, self.parts)
 
     def out_of_date(self, url, path, cache_data):
         if SETTINGS.get("check-out-of-date-urls") is False:
